"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const anser_1 = __importDefault(require("anser"));
const highlightjs_1 = __importDefault(require("highlightjs"));
const katex_1 = __importDefault(require("katex"));
const marked_1 = __importDefault(require("marked"));
const ipynb2html_core_1 = require("ipynb2html-core");
exports.NbRenderer = ipynb2html_core_1.NbRenderer;
const markdownRenderer_1 = __importDefault(require("./markdownRenderer"));
var version_1 = require("./version");
exports.version = version_1.default;
var readNotebookTitle_1 = require("./readNotebookTitle");
exports.readNotebookTitle = readNotebookTitle_1.default;
const defaultKatexOpts = {
    displayMode: true,
    throwOnError: false,
};
function hljsCodeHighlighter(code, lang) {
    return highlightjs_1.default.getLanguage(lang)
        ? highlightjs_1.default.highlight(lang, code).value
        : code;
}
/**
 * Builds a full-fledged Jupyter Notebook renderer.
 *
 * It supports rendering of Markdown cells with math (using marked and KaTeX),
 * code highlighting (using highlight.js), rendering of ANSI escape sequences
 * (using Anser) and SageMath-style math outputs. All of them may be overridden
 * via *opts*.
 *
 * It returns a "callable object" that exposes one renderer function for each
 * of the Notebook's AST nodes. You can easily replace any of the functions to
 * modify behaviour of the renderer.
 *
 * @example  // Node.js
 *   import * as fs from 'fs'
 *   import * as ipynb from 'ipynb2html'
 *   import { Document } from 'nodom'
 *
 *   const renderNotebook = ipynb.createRenderer(new Document())
 *   const notebook = JSON.parse(fs.readFileSync('./example.ipynb', 'utf8'))
 *
 *   console.log(renderNotebook(notebook).outerHTML)
 *
 * @example  // Browser
 *   const render = ipynb2html.createRenderer(document)
 *   document.body.appendChild(render(notebook))
 *
 * @param document The `Document` object from the browser's native DOM or any
 *   fake/virtual DOM library (e.g. nodom). The only required method is
 *   `createElement`.
 * @param opts The renderer options.
 * @return A configured instance of the Notebook renderer.
 */
function createRenderer(document, opts = {}) {
    let { ansiCodesRenderer, codeHighlighter, dataRenderers = {}, markdownRenderer } = opts;
    const katexOpts = { ...defaultKatexOpts, ...opts.katexOpts };
    const elementCreator = ipynb2html_core_1.createElementCreator(document.createElement.bind(document), opts.classPrefix);
    // The following ifs for the imported modules are for the browser bundle
    // without dependencies.
    if (!ansiCodesRenderer) {
        if (anser_1.default) {
            ansiCodesRenderer = (input) => anser_1.default.ansiToHtml(anser_1.default.escapeForHtml(input));
        }
        else if (AnsiUp) {
            const ansiUp = new AnsiUp();
            ansiCodesRenderer = ansiUp.ansi_to_html.bind(ansiUp);
        }
    }
    if (!codeHighlighter && highlightjs_1.default) {
        codeHighlighter = hljsCodeHighlighter;
    }
    if (!markdownRenderer && marked_1.default) {
        if (katex_1.default) {
            markdownRenderer = markdownRenderer_1.default(opts.markedOpts, katexOpts);
        }
        else {
            markdownRenderer = (text) => marked_1.default.parse(text, opts.markedOpts);
        }
    }
    if (!dataRenderers['text/html'] && katex_1.default) {
        const mathRenderer = (tex) => katex_1.default.renderToString(tex, katexOpts);
        dataRenderers['text/html'] = ipynb2html_core_1.createHtmlRenderer({ elementCreator, mathRenderer });
    }
    return new ipynb2html_core_1.NbRenderer(elementCreator, {
        ansiCodesRenderer,
        codeHighlighter,
        dataRenderers,
        markdownRenderer,
        ...opts,
    });
}
exports.createRenderer = createRenderer;
//# sourceMappingURL=index.js.map